==> huaweicloudsdkosm-3.1.51-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/show_signed_latest_published_agreement_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSignedLatestPublishedAgreementResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_signed_latest': 'bool'
    }

    attribute_map = {
        'is_signed_latest': 'is_signed_latest'
    }

    def __init__(self, is_signed_latest=None):
        """ShowSignedLatestPublishedAgreementResponse

        The model defined in huaweicloud sdk

        :param is_signed_latest: 是否签署
        :type is_signed_latest: bool
        """
        
        super(ShowSignedLatestPublishedAgreementResponse, self).__init__()

        self._is_signed_latest = None
        self.discriminator = None

        if is_signed_latest is not None:
            self.is_signed_latest = is_signed_latest

    @property
    def is_signed_latest(self):
        """Gets the is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.

        是否签署

        :return: The is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.
        :rtype: bool
        """
        return self._is_signed_latest

    @is_signed_latest.setter
    def is_signed_latest(self, is_signed_latest):
        """Sets the is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.

        是否签署

        :param is_signed_latest: The is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.
        :type is_signed_latest: bool
        """
        self._is_signed_latest = is_signed_latest

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSignedLatestPublishedAgreementResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkosm-3.1.145-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/show_signed_latest_published_agreement_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSignedLatestPublishedAgreementResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_signed_latest': 'bool'
    }

    attribute_map = {
        'is_signed_latest': 'is_signed_latest'
    }

    def __init__(self, is_signed_latest=None):
        r"""ShowSignedLatestPublishedAgreementResponse

        The model defined in huaweicloud sdk

        :param is_signed_latest: 是否签署
        :type is_signed_latest: bool
        """
        
        super(ShowSignedLatestPublishedAgreementResponse, self).__init__()

        self._is_signed_latest = None
        self.discriminator = None

        if is_signed_latest is not None:
            self.is_signed_latest = is_signed_latest

    @property
    def is_signed_latest(self):
        r"""Gets the is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.

        是否签署

        :return: The is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.
        :rtype: bool
        """
        return self._is_signed_latest

    @is_signed_latest.setter
    def is_signed_latest(self, is_signed_latest):
        r"""Sets the is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.

        是否签署

        :param is_signed_latest: The is_signed_latest of this ShowSignedLatestPublishedAgreementResponse.
        :type is_signed_latest: bool
        """
        self._is_signed_latest = is_signed_latest

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSignedLatestPublishedAgreementResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
